@@ -1,8 +1,8 @@
 <?php
 /*
- * $Horde: kronolith/index.php,v 1.19.2.1 2002/04/23 17:59:49 chuck Exp $
+ * $Horde: kronolith/index.php,v 1.19.2.3 2003/02/13 00:48:04 jan Exp $
  *
- * Kronolith: Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
+ * Kronolith: Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL). If you did
  * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
@@ -15,7 +15,7 @@ $kronolith_configured = (@is_readable(KRONOLITH_BASE . '/config/conf.php') &&
 
 if ($kronolith_configured) {
     include_once KRONOLITH_BASE . '/lib/base.php';
-    
+
     $uri = $prefs->getValue('defaultview') . '.php';
     if ($uri == '.php') {
         $uri = 'month.php';
@@ -23,13 +23,8 @@ if ($kronolith_configured) {
     if (!empty($_SERVER['QUERY_STRING'])) {
         $uri .= '?' . $_SERVER['QUERY_STRING'];
     }
-    
+
     header('Location: ' . Horde::applicationUrl($uri, true));
-    exit;
-    
-/* Kronolith isn't configured */
 } else {
     include KRONOLITH_BASE . '/templates/index/notconfigured.inc';
 }
-
-?>
