@@ -1,9 +1,9 @@
 <?php
 /*
- * $Horde: kronolith/menu.php,v 1.14 2002/01/24 22:29:54 chuck Exp $
+ * $Horde: kronolith/menu.php,v 1.14.2.2 2003/02/13 00:48:04 jan Exp $
  *
- * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
- * Copyright 1999, 2000 Jon Parise <jon@horde.org>
+ * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL). If you did
  * not receive such a file, see also http://www.fsf.org/copyleft/gpl.html.
@@ -32,13 +32,11 @@ if (!$timestamp) {
     $timestamp = mktime(0, 0, 0, $month, $day, $year);
 }
 $append = "?timestamp=$timestamp";
-  
+
 include KRONOLITH_TEMPLATES . '/menu/menu.inc';
-require './status.php';
+require KRONOLITH_BASE . '/status.php';
 
 /* Include the JavaScript for the help system (if enabled). */
 if ($conf['user']['online_help'] && $browser->hasFeature('javascript')) {
     Help::javascript();
 }
-
-?>
