@@ -1,8 +1,8 @@
 <?php
 /*
- * $Horde: kronolith/week.php,v 1.13.2.1 2002/03/19 02:10:41 chuck Exp $
+ * $Horde: kronolith/week.php,v 1.13.2.4 2003/02/13 00:48:05 jan Exp $
  *
- * Copyright 1999, 2000 Charles J. Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2003 Charles J. Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (GPL).  If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
@@ -32,10 +32,22 @@ if ($conf['compress_pages']) {
 }
 
 require KRONOLITH_TEMPLATES . '/common-header.inc';
-require './menu.php';
+
+$print_view = (Horde::getFormData('print') == 'true');
+if ($print_view) {
+    require KRONOLITH_TEMPLATES . '/javascript/print.inc';
+} else {
+    $print_link = Kronolith::addParameter('week.php', 'week=' . $week);
+    $print_link = Kronolith::addParameter($print_link, 'year=' . $year);
+    $print_link = Kronolith::addParameter($print_link, 'print=true');
+    $print_link = Horde::url($print_link);
+    if ($browser->hasFeature('javascript')) {
+        include KRONOLITH_TEMPLATES . '/javascript/open_print_win.js';
+    }
+
+    require KRONOLITH_BASE . '/menu.php';
+}
 
 $weekOb->html(KRONOLITH_TEMPLATES);
 
 require KRONOLITH_TEMPLATES . '/common-footer.inc';
-
-?>
